@@ -11,13 +11,11 @@ import os
 import re
 from enum import Enum
 from pathlib import Path
-from random import randint
-from time import sleep
-from typing import Callable, Dict, Set, Union
+from typing import Dict, Set, Union
 
 import requests
 from bs4 import BeautifulSoup, Comment  # type:ignore[import]
-from PyPDF2 import PdfReader  # type:ignore[import]
+from pypdf import PdfReader  # type:ignore[import]
 from requests.models import CaseInsensitiveDict
 
 _logger = logging.getLogger("edi_energy_scraper")
@@ -52,7 +50,6 @@ class EdiEnergyScraper:
         root_url: str = "https://www.edi-energy.de",
         path_to_mirror_directory: Union[Path, str] = Path("edi_energy_de"),
         # HTML and PDF files will be stored relative to this
-        dos_waiter: Callable = lambda: sleep(randint(1, 10)),
     ):
         """
         Initialize the Scaper by providing the URL, a path to save the files to and a function that prevents DOS.
@@ -65,7 +62,6 @@ class EdiEnergyScraper:
             self._root_dir = Path(path_to_mirror_directory)
         else:
             self._root_dir = path_to_mirror_directory
-        self._dos_waiter = dos_waiter
 
     def _get_soup(self, url: str) -> BeautifulSoup:
         """
@@ -76,7 +72,6 @@ class EdiEnergyScraper:
         response = requests.get(url, timeout=5)
         soup = BeautifulSoup(response.content, "html.parser")
         EdiEnergyScraper.remove_comments(soup)
-        self._dos_waiter()  # <-- DOS protection, usually a blocking method (e.g. time.sleep(...))
         return soup
 
     def _download_and_save_pdf(self, epoch: Epoch, file_basename: str, link: str) -> Path:
@@ -178,7 +173,7 @@ class EdiEnergyScraper:
         """
         Removes thes HTML comments from the given soup.
         """
-        for html_comment in soup.findAll(text=lambda text: isinstance(text, Comment)):
+        for html_comment in soup.findAll(string=lambda text: isinstance(text, Comment)):
             html_comment.extract()
 
     def get_documents_page_link(self, index_soup) -> str:
@@ -211,7 +206,7 @@ class EdiEnergyScraper:
         from the "Dokumente" sub page soup.
         """
         result: Dict[Epoch, str] = {}
-        for (doc_text, doc_epoch) in EdiEnergyScraper._docs_texts.items():
+        for doc_text, doc_epoch in EdiEnergyScraper._docs_texts.items():
             _logger.debug("searching for '%s'", doc_text)
             result[doc_epoch] = document_soup.find("a", string=re.compile(r"\s*" + doc_text + r"\s*")).attrs["href"]
         # result now looks like this:
